==> web-fw2_2_2.zip: web-fw2_2_2/j2src/weber/org/itscool/weber/action/Globals.java <==
package org.itscool.weber.action;

/**
 * t[[Nʂŗp`Ǘ܂
 * @author KANO
 * @since jdk1.4.1
 * @version 1.00A 2004/11/1
*/
public class Globals{
    /**
     * t[[N̏t@C̃pX
     * <code>CONFIG_NAME</code>
     */
    public static final String CONFIG_NAME =
        "/WEB-INF/weber-config.xml";
    
    public static final String DAO_CONFIG_NAME =
        "/WEB-INF/dao-config.xml";
    /**
     * t[[ÑbZ[Wt@C̃pX
     * <code>MESSAGE_NAME</code>
     */
    public static final String MESSAGE_NAME =
        "/WEB-INF/weber-message.xml";
    /**
     * ̓G[^O肷邽߂̘_ł 
     */
    public static final String REQ_PARAM_FORM_ERR =
        "org.itscool.weber.action.INPUT_ERROR";
    
    /**
     * ̓G[^O肷邽߂̘_ł 
     */
    public static final String REQ_PARAM_SYSTEM_ERR =
        "org.itscool.weber.action.SYSTEM_ERROR";
    
    /**
     *  
    */
	public static final String REQ_PARAM_SYSTEM_ERR_MSG =
		"org.itscool.weber.action.SYSTEM_ERROR_MSG";
    
    /**
     * F؏肷邽߂̃NGXgp[^   
     */
    public static final String REQ_PARAM_USER =
        "org.itscool.weber.action.USER";
    
    public static final String RET_SUCCESS="success";
    /**
     * org.itscool.action.NoOpActioñtH[h
     * Fؐ̃tH[h̘_
     * ANVɌtꍇ
     * NoOpAction`ꍇ̓tH[h"success"ɃZbg
     */
    public static final String RET_ROLE_SUCCESS =
        "org.itscool.weber.action.ROLE_SUCCESS";
    
    /**
     * F؃G[̃tH[h̘_
     * ANVɌtꍇ
     * tH[hhfailhZbgiK{j   
     */
    public static final String RET_ROLE_FAIL =
        "org.itscool.weber.action.ROLE_FAIL";
    
    /**
     * <code>SELECT_TAG_VALUE</code>
     */
    public static final String SELECT_TAG_VALUE =
        "org.itscool.tag.SelectTag.SELECT_TAG_VALUE";
    /**
     * <code>SELECT_TAG_NAME</code>
     */
    public static final String SELECT_TAG_NAME =
        "org.itscool.tag.SelectTag.SELECT_TAG_NAME";
    
    /**
     * INCLUDENGXgp[^
     */
    public static final String REQ_PARAM_INCLUDE =
        "org.itscool.stylist.include.INCLUDE.";
            
    /**
     * INCLUDE BODY NGXgp[^
     */
//  2005.05.20 -start-
    //public static final String REQ_PARAM_INCLUDE_CONTENTS_NAME =
    //    REQ_PARAM_INCLUDE + "body.contentsname";
//  2005.05.20 -end-
}

==> web-fw3_0_2.zip: web-fw3_0_2/j2src/weber/org/itscool/weber/action/Globals.java <==
package org.itscool.weber.action;

/**
 * t[[Nʂŗp`Ǘ܂
 * @author KANO
 * @since jdk1.4.1
 * @version 1.00A 2004/11/1
*/
public class Globals{
    /**
     * t[[N̏t@C̃pX
     * <code>CONFIG_NAME</code>
     */
    public static final String CONFIG_NAME =
        "/WEB-INF/weber-config.xml";
    
    public static final String DAO_CONFIG_NAME =
        "/WEB-INF/dao-config.xml";
    /**
     * t[[ÑbZ[Wt@C̃pX
     * <code>MESSAGE_NAME</code>
     */
    public static final String MESSAGE_NAME =
        "/WEB-INF/weber-message.xml";
    /**
     * ̓G[^O肷邽߂̘_ł 
     */
    public static final String REQ_PARAM_FORM_ERR =
        "org.itscool.weber.action.INPUT_ERROR";
    
    /**
     * ̓G[^O肷邽߂̘_ł 
     */
    public static final String REQ_PARAM_SYSTEM_ERR =
        "org.itscool.weber.action.SYSTEM_ERROR";
    
    /**
     *  
    */
	public static final String REQ_PARAM_SYSTEM_ERR_MSG =
		"org.itscool.weber.action.SYSTEM_ERROR_MSG";
    
    /**
     * F؏肷邽߂̃NGXgp[^   
     */
//modify 2006/08/14 kano start
//    public static final String REQ_PARAM_USER =
//        "org.itscool.weber.action.USER";
	public static final String REQ_PARAM_USER =
        "org_itscool_weber_action_USER";
//modify 2006/08/14 kano end
	
    public static final String RET_SUCCESS="success";
    
    public static final String RET_NOFORWARD="noforward";
    
    /**
     * org.itscool.action.NoOpActioñtH[h
     * Fؐ̃tH[h̘_
     * ANVɌtꍇ
     * NoOpAction`ꍇ̓tH[h"success"ɃZbg
     */
    public static final String RET_ROLE_SUCCESS =
        "org.itscool.weber.action.ROLE_SUCCESS";
    
    /**
     * F؃G[̃tH[h̘_
     * ANVɌtꍇ
     * tH[hhfailhZbgiK{j   
     */
    public static final String RET_ROLE_FAIL =
        "org.itscool.weber.action.ROLE_FAIL";
    
    /**
     * <code>SELECT_TAG_VALUE</code>
     */
    public static final String SELECT_TAG_VALUE =
        "org.itscool.tag.SelectTag.SELECT_TAG_VALUE";
    /**
     * <code>SELECT_TAG_NAME</code>
     */
    public static final String SELECT_TAG_NAME =
        "org.itscool.tag.SelectTag.SELECT_TAG_NAME";
    
    /**
     * INCLUDENGXgp[^
     */
    public static final String REQ_PARAM_INCLUDE =
        "org.itscool.stylist.include.INCLUDE.";
            
    /**
     * INCLUDE BODY NGXgp[^
     */
//  2005.05.20 -start-
    //public static final String REQ_PARAM_INCLUDE_CONTENTS_NAME =
    //    REQ_PARAM_INCLUDE + "body.contentsname";
//  2005.05.20 -end-
}
